# Zwlib
Zwlib is a package that provides a series of utility functions for Convo studio and AIforyou products.

## Features
- Easy-to-use API request functions with built-in error handling
- Functions for handling image, video, and payment meta-data
- Building NLP Models
- Compatible with Python 3.6 and above

## Installation
To install Zwlib, simply run:

```bash
pip install zwlib
